# -*- coding: utf-8 -*-


class ApiError(Exception):
    """Base class for exceptions in this module."""
    pass
